@@ -34,3 +34,9 @@
              "\nInstall with BiocManager::install('ComplexHeatmap').")
     }
 }
+
+.error_if_no_mass_because <- function(case) {
+    if (!requireNamespace("MASS", quietly = TRUE)) {
+        stop(paste0("MASS installation required for adding ", case, "."))
+    }
+}
